HIRISE_api.models.metrics — HIRISE_api documentation

# HIRISE_api.models.metrics

Functions

`calculate_metrics`(model, labels[, verbose]) | Function that calulates metrics including, rand score, adjusted rand score, mutual information score, normalized mutual information score, adjusted mutual information score, balanced accuracy score, completeness score, homogeniety score and v-score for a given model.
`classification_metrics_dataframe`(model_list, ...) | Fucntion that creates a metrics dataframe based on the calculated metrics for each model in the model list specified by the user.
`generate_precision_dataframe`(folder_path, ...) | Function that returns a generated a dataframe of all the precision values evaluated for a true and predicted labels after classifiaction analysis on a dataset.
`print_confusion_matrix`(folder_path, ...[, ...]) | Function that prints the confusion matrix metric for a given set of image clustering results and the associated images.